@@ -119,7 +119,7 @@ sub _headers {
 sub _start_line {
   my ($self, $msg) = @_;
 
-  # Prepare start line chunk
+  # Prepare start-line chunk
   my $buffer = $msg->get_start_line_chunk($self->{offset});
   my $written = defined $buffer ? length $buffer : 0;
   $self->{write} -= $written;
@@ -149,11 +149,11 @@ sub _write {
     $headers->connection($self->keep_alive ? 'keep-alive' : 'close')
       unless $headers->connection;
 
-    # Switch to start line
+    # Switch to start-line
     @$self{qw(http_state write)} = ('start_line', $msg->start_line_size);
   }
 
-  # Start line
+  # Start-line
   my $chunk = '';
   $chunk .= $self->_start_line($msg) if $self->{http_state} eq 'start_line';
 
@@ -234,7 +234,7 @@ Emitted for unexpected C<1xx> responses that will be ignored.
 
   $tx->on(unexpected => sub {
     my $tx = shift;
-    $tx->res->on(finish => sub { say 'Followup response is finished.' });
+    $tx->res->on(finish => sub { say 'Follow-up response is finished.' });
   });
 
 =head2 upgrade
@@ -262,7 +262,7 @@ and implements the following new ones.
   my $previous = $tx->previous;
   $tx          = $tx->previous(Mojo::Transaction::HTTP->new);
 
-Previous transaction that triggered this followup transaction, usually a
+Previous transaction that triggered this follow-up transaction, usually a
 L<Mojo::Transaction::HTTP> object.
 
   # Paths of previous requests
@@ -302,7 +302,7 @@ Check if connection can be kept alive.
 
   my $redirects = $tx->redirects;
 
-Return a list of all previous transactions that preceded this followup
+Return a list of all previous transactions that preceded this follow-up
 transaction.
 
   # Paths of all previous requests
