@@ -43,7 +43,7 @@ has types     => sub { Mojolicious::Types->new };
 has validator => sub { Mojolicious::Validator->new };
 
 our $CODENAME = 'Tiger Face';
-our $VERSION  = '5.72';
+our $VERSION  = '5.73';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -108,7 +108,7 @@ sub dispatch {
 
   # Routes
   $plugins->emit_hook(before_routes => $c);
-  $c->render_not_found
+  $c->helpers->reply->not_found
     unless $tx->res->code || $self->routes->dispatch($c) || $tx->res->code;
 }
 
@@ -154,10 +154,9 @@ sub new {
   # Hide controller attributes/methods
   $r->hide(qw(app continue cookie every_cookie every_param));
   $r->hide(qw(every_signed_cookie finish flash helpers match on param));
-  $r->hide(qw(redirect_to render render_exception render_later render_maybe));
-  $r->hide(qw(render_not_found render_to_string rendered req res respond_to));
-  $r->hide(qw(send session signed_cookie stash tx url_for validation write));
-  $r->hide(qw(write_chunk));
+  $r->hide(qw(redirect_to render render_later render_maybe render_to_string));
+  $r->hide(qw(rendered req res respond_to send session signed_cookie stash));
+  $r->hide(qw(tx url_for validation write write_chunk));
 
   # Check if we have a log directory that is writable
   my $mode = $self->mode;
@@ -195,7 +194,7 @@ sub _exception {
   my ($next, $c) = @_;
   local $SIG{__DIE__}
     = sub { ref $_[0] ? CORE::die($_[0]) : Mojo::Exception->throw(@_) };
-  $c->render_exception($@) unless eval { $next->(); 1 };
+  $c->helpers->reply->exception($@) unless eval { $next->(); 1 };
 }
 
 1;
@@ -563,6 +562,9 @@ request.
   # Remove value
   my $foo = delete $app->defaults->{foo};
 
+  # Assign multiple values at once
+  $app->defaults(foo => 'test', bar => 23);
+
 =head2 dispatch
 
   $app->dispatch(Mojolicious::Controller->new);
@@ -646,9 +648,11 @@ L<Mojolicious> distribution see L<Mojolicious::Plugins/"PLUGINS">.
   $app->start(@ARGV);
 
 Start the command line interface for your application, for a full list of
-commands available by default see L<Mojolicious::Commands/"COMMANDS">.
+commands available by default see L<Mojolicious::Commands/"COMMANDS">. Note
+that the options C<-h>/C<--help>, C<--home> and C<-m>/C<--mode>, which are
+shared by all commands, will be parsed from C<@ARGV> during compile time.
 
-  # Always start daemon and ignore @ARGV
+  # Always start daemon
   $app->start('daemon', '-l', 'http://*:8080');
 
 =head2 startup
