@@ -13,7 +13,6 @@ has message    => sub { shift->extract_usage . "\nCommands:\n" };
 has namespaces => sub { ['Mojolicious::Command'] };
 
 sub detect {
-  my ($self, $guess) = @_;
 
   # PSGI (Plack only for now)
   return 'psgi' if defined $ENV{PLACK_ENV};
@@ -22,24 +21,9 @@ sub detect {
   return 'cgi' if defined $ENV{PATH_INFO} || defined $ENV{GATEWAY_INTERFACE};
 
   # Nothing
-  return $guess;
+  return undef;
 }
 
-# Command line options for MOJO_HELP, MOJO_HOME and MOJO_MODE
-sub _args {
-  return if __PACKAGE__->detect;
-
-  my $save
-    = Getopt::Long::Configure(qw(no_auto_abbrev no_ignore_case pass_through));
-  GetOptionsFromArray shift,
-    'h|help'   => \$ENV{MOJO_HELP},
-    'home=s'   => \$ENV{MOJO_HOME},
-    'm|mode=s' => \$ENV{MOJO_MODE};
-  Getopt::Long::Configure($save);
-}
-
-BEGIN { _args([@ARGV]) }
-
 sub run {
   my ($self, $name, @args) = @_;
 
@@ -47,14 +31,14 @@ sub run {
   return $self->app if defined $ENV{MOJO_APP_LOADER};
 
   # Try to detect environment
-  $name = $self->detect($name) unless $ENV{MOJO_NO_DETECT};
+  if (!$ENV{MOJO_NO_DETECT} && (my $env = $self->detect)) { $name = $env }
 
   # Run command
   if ($name && $name =~ /^\w+$/ && ($name ne 'help' || $args[0])) {
 
     # Help
     $name = shift @args if my $help = $name eq 'help';
-    $help = $ENV{MOJO_HELP} = $ENV{MOJO_HELP} ? 1 : $help;
+    $help = $ENV{MOJO_HELP} ||= $help;
 
     # Remove options shared by all commands before loading the command
     _args(\@args);
@@ -91,6 +75,22 @@ sub run {
 
 sub start_app { shift; Mojo::Server->new->build_app(shift)->start(@_) }
 
+# Command line options for MOJO_HELP, MOJO_HOME and MOJO_MODE
+sub _args {
+  return if __PACKAGE__->detect;
+
+  my $save
+    = Getopt::Long::Configure(qw(no_auto_abbrev no_ignore_case pass_through));
+  GetOptionsFromArray shift,
+    'h|help'   => \$ENV{MOJO_HELP},
+    'home=s'   => \$ENV{MOJO_HOME},
+    'm|mode=s' => \$ENV{MOJO_MODE};
+  Getopt::Long::Configure($save);
+}
+
+# Do not remove options from @ARGV
+BEGIN { _args([@ARGV]) }
+
 sub _command {
   my ($module, $fatal) = @_;
   return $module->isa('Mojolicious::Command') ? $module : undef
@@ -299,9 +299,8 @@ implements the following new ones.
 =head2 detect
 
   my $env = $commands->detect;
-  my $env = $commands->detect($guess);
 
-Try to detect environment.
+Try to detect environment or return C<undef> if none could be detected.
 
 =head2 run
 
@@ -316,9 +315,11 @@ disabled with the C<MOJO_NO_DETECT> environment variable.
   Mojolicious::Commands->start_app('MyApp');
   Mojolicious::Commands->start_app(MyApp => @ARGV);
 
-Load application from class and start the command line interface for it.
+Load application from class and start the command line interface for it. Note
+that the options C<-h>/C<--help>, C<--home> and C<-m>/C<--mode>, which are
+shared by all commands, will be parsed from C<@ARGV> during compile time.
 
-  # Always start daemon for application and ignore @ARGV
+  # Always start daemon for application
   Mojolicious::Commands->start_app('MyApp', 'daemon', '-l', 'http://*:8080');
 
 =head1 SEE ALSO
