@@ -65,9 +65,47 @@ sub every_cookie {
   [map { $_->value } @{shift->req->every_cookie(shift)}];
 }
 
-sub every_param { _param(@_) }
+sub every_param {
+  my ($self, $name) = @_;
 
-sub every_signed_cookie { _signed_cookie(@_) }
+  # Captured unreserved values
+  my $captures = $self->stash->{'mojo.captures'} ||= {};
+  if (!$RESERVED{$name} && defined(my $value = $captures->{$name})) {
+    return ref $value eq 'ARRAY' ? $value : [$value];
+  }
+
+  # Uploads or param values
+  my $req     = $self->req;
+  my $uploads = $req->every_upload($name);
+  return @$uploads ? $uploads : $req->every_param($name);
+}
+
+sub every_signed_cookie {
+  my ($self, $name) = @_;
+
+  my $secrets = $self->stash->{'mojo.secrets'};
+  my @results;
+  for my $value (@{$self->every_cookie($name)}) {
+
+    # Check signature with rotating secrets
+    if ($value =~ s/--([^\-]+)$//) {
+      my $signature = $1;
+
+      my $valid;
+      for my $secret (@$secrets) {
+        my $check = Mojo::Util::hmac_sha1_sum($value, $secret);
+        ++$valid and last if Mojo::Util::secure_compare($signature, $check);
+      }
+      if ($valid) { push @results, $value }
+
+      else { $self->app->log->debug(qq{Cookie "$name" has bad signature.}) }
+    }
+
+    else { $self->app->log->debug(qq{Cookie "$name" not signed.}) }
+  }
+
+  return \@results;
+}
 
 sub finish {
   my $self = shift;
@@ -126,7 +164,7 @@ sub param {
   }
 
   # Value
-  return _param($self, $name)->[-1] unless @_;
+  return $self->every_param($name)->[-1] unless @_;
 
   # Override values
   $captures->{$name} = @_ > 1 ? [@_] : $_[0];
@@ -158,7 +196,8 @@ sub render {
   return defined $output ? Mojo::ByteStream->new($output) : undef if $ts;
 
   # Maybe
-  return $maybe ? undef : !$self->render_not_found unless defined $output;
+  return $maybe ? undef : !$self->helpers->reply->not_found
+    unless defined $output;
 
   # Prepare response
   $plugins->emit_hook(after_render => $self, \$output, $format);
@@ -168,14 +207,10 @@ sub render {
   return !!$self->rendered($self->stash->{status});
 }
 
-sub render_exception { shift->helpers->reply->exception(@_) }
-
 sub render_later { shift->stash('mojo.rendered' => 1) }
 
 sub render_maybe { shift->render(@_, 'mojo.maybe' => 1) }
 
-sub render_not_found { shift->helpers->reply->not_found }
-
 sub render_to_string { shift->render(@_, 'mojo.to_string' => 1) }
 
 sub rendered {
@@ -272,7 +307,7 @@ sub signed_cookie {
   return map { $self->signed_cookie($_) } @$name if ref $name eq 'ARRAY';
 
   # Request cookie
-  return _signed_cookie($self, $name)->[-1] unless defined $value;
+  return $self->every_signed_cookie($name)->[-1] unless defined $value;
 
   # Response cookie
   my $checksum
@@ -352,48 +387,6 @@ sub write_chunk {
   return $self->rendered;
 }
 
-sub _param {
-  my ($self, $name) = @_;
-
-  # Captured unreserved values
-  my $captures = $self->stash->{'mojo.captures'} ||= {};
-  if (!$RESERVED{$name} && defined(my $value = $captures->{$name})) {
-    return ref $value eq 'ARRAY' ? $value : [$value];
-  }
-
-  # Uploads or param values
-  my $req     = $self->req;
-  my $uploads = $req->every_upload($name);
-  return @$uploads ? $uploads : $req->every_param($name);
-}
-
-sub _signed_cookie {
-  my ($self, $name) = @_;
-
-  my $secrets = $self->stash->{'mojo.secrets'};
-  my @results;
-  for my $value (@{$self->every_cookie($name)}) {
-
-    # Check signature with rotating secrets
-    if ($value =~ s/--([^\-]+)$//) {
-      my $signature = $1;
-
-      my $valid;
-      for my $secret (@$secrets) {
-        my $check = Mojo::Util::hmac_sha1_sum($value, $secret);
-        ++$valid and last if Mojo::Util::secure_compare($signature, $check);
-      }
-      if ($valid) { push @results, $value }
-
-      else { $self->app->log->debug(qq{Cookie "$name" has bad signature.}) }
-    }
-
-    else { $self->app->log->debug(qq{Cookie "$name" not signed.}) }
-  }
-
-  return \@results;
-}
-
 1;
 
 =encoding utf8
@@ -678,16 +671,12 @@ L</"stash">.
   # Render template "foo/bar.*.*"
   $c->render(template => 'foo/bar');
 
+  # Render template "test.*.*" with arbitrary values "foo" and "bar"
+  $c->render(template => 'test', foo => 'test', bar => 23);
+
   # Render template "test.xml.*"
   $c->render('test', format => 'xml');
 
-=head2 render_exception
-
-  $c = $c->render_exception('Oops!');
-  $c = $c->render_exception(Mojo::Exception->new('Oops!'));
-
-Alias for L<Mojolicious::Plugin::DefaultHelpers/"reply-E<gt>exception">.
-
 =head2 render_later
 
   $c = $c->render_later;
@@ -714,12 +703,6 @@ could be generated, takes the same arguments as L</"render">.
   # Render template "index_local" only if it exists
   $c->render_maybe('index_local') or $c->render('index');
 
-=head2 render_not_found
-
-  $c = $c->render_not_found;
-
-Alias for L<Mojolicious::Plugin::DefaultHelpers/"reply-E<gt>not_found">.
-
 =head2 render_to_string
 
   my $output = $c->render_to_string('foo/index', format => 'pdf');
@@ -897,6 +880,9 @@ reserved for internal use.
   # Remove value
   my $foo = delete $c->stash->{foo};
 
+  # Assign multiple values at once
+  $c->stash(foo => 'test', bar => 23);
+
 =head2 url_for
 
   my $url = $c->url_for;
